"""Tests for consistency.spacing check."""
from __future__ import absolute_import

from .check import Check

from proselint.checks.consistency import spacing as chk


class TestCheck(Check):
    """The test class for consistency.spacing."""

    __test__ = True

    @property
    def this_check(self):
        """Boilerplate."""
        return chk

    def test_smoke(self):
        """Basic smoke test for consistency.spacing."""
        assert self.passes("""Smoke phrase with nothing flagged.""")
        assert self.passes(
            """This is good. Only one space each time. Every time.""")
        assert not self.passes("""This is bad.  Not consistent. At all.""")



"""Check that the CLI can handle invalid characters."""

import os.path as pth
import subprocess


def test_invalid_characters():
    """Ensure that a file with illegal characters does not break us."""
    try:
        output = ""
        curr_dir = pth.dirname(pth.abspath(__file__))
        test_file = pth.join(curr_dir, "illegal-chars.txt")
        # We only print out exception text and continue after printing a trace,
        # so the only way (currently) to test for failure is to look for the
        # exception text. Refactoring the command line function would let us
        # write better tests (one day).
        output = str(subprocess.check_output(
            ["proselint", test_file],
            stderr=subprocess.STDOUT
        ))
    except subprocess.CalledProcessError as e:
        # Non-zero return codes are OK, but what did we catch?
        print("Non-zero return value: will proceed. %s" % e)
        output += str(e.output)
    except Exception:
        assert(not "Unknown Exception Occurred")

    assert("UnicodeDecodeError" not in output)  # Failed to process the file
    assert("FileNotFoundError" not in output)   # Failed to find our test file



"""Tests for misc.commercialese check."""
from __future__ import absolute_import

from .check import Check

from proselint.checks.misc import commercialese as chk


class TestCheck(Check):
    """The test class for misc.commercialese."""

    __test__ = True

    @property
    def this_check(self):
        """Boilerplate."""
        return chk

    def test_smoke(self):
        """Basic smoke test for misc.commercialese."""
        assert self.passes("""Smoke phrase with nothing flagged.""")
        assert not self.passes("""We regret to inform you of this.""")



"""Tests for weasel_words.misc check."""
from __future__ import absolute_import

from .check import Check

from proselint.checks.weasel_words import misc as chk
from nose import SkipTest


class TestCheck(Check):
    """The test class for weasel_words.misc."""

    raise SkipTest

    __test__ = True

    @property
    def this_check(self):
        """Boilerplate."""
        return chk

    def test_smoke(self):
        """Basic smoke test for weasel_words.misc."""
        assert self.passes("""Smoke phrase with nothing flagged.""")
        # FIXME add test when check is implemented



"""Installation script for proselint."""

import io
import os
from setuptools import setup, find_packages

from proselint.version import __version__

DESCRIPTION = "A linter for prose."

base_url = 'http://github.com/amperser/proselint'

here = os.path.abspath(os.path.dirname(__file__))

try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

setup(
    name='proselint',
    version=__version__,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    url=base_url,
    download_url="{}/tarball/{}".format(base_url, __version__),
    author='Amperser Labs',
    author_email='hello@amperser.com',
    license='BSD',
    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
    packages=find_packages(
        exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    package_data={'': ['demo.md', '.proselintrc']},
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'proselint = proselint.command_line:proselint',
        ],
    },
    install_requires=[
        'click',
        'future',
        'six'
    ])



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Test GMEU entry 'a', part B."""

from proselint.tools import assert_error
from nose import SkipTest


def test_a_distributive():
    """Use a over per in the distributive sense."""
    raise SkipTest

    sentences = [
        "An apple per day keeps the doctor away.",
        "I sleep eight hours per night.",
        "Their policy allows one golf cart a couple.",
        "The company donated five books a student.",
        "Our a-unit cost is less than $1000.",
        "The $50-a-parent fee seems unreasonably high."
    ]

    error_check_name = "misc.a_distributive"

    for sentence in sentences:
        yield assert_error, sentence, error_check_name
